@@ -133,7 +133,7 @@ def create_response_proto_to_dict(res: BatchCreateResponse) -> Dict[str, bytes]:
             "investment_amount": f(res.investment_amount, dtype=np.float32),
             "price": f(res.price, dtype=np.float32),
             "margin": f(res.margin, dtype=np.float16),
-            "fraction": f(res.fraction, dtype=str),
+            "fraction": f(res.fraction, dtype=bool),
             "multiplier_1": f(res.multiplier_1, dtype=np.float16),
             "multiplier_2": f(res.multiplier_2, dtype=np.float16),
             "delta": f(res.delta, dtype=np.float32),
